#!/bin/bash
FULLPATH=`dirname "$0"`/`basename "$0"`
BASE=`readlink -f "$FULLPATH"`
BASEPATH=`dirname $BASE`

KM_NAME=ixgbe
KM_VER=4.3.15
KM_TARGET_DIR=/lib/modules/2.6.32-504.el6.x86_64/kernel/drivers/net/ixgbe/

KM_NV=${KM_NAME}-${KM_VER}
KM_GZ_FILE=${KM_NV}.tar.gz
UNTAR_DIR=${KM_NV}

TEMPLATE_FILE=template.spec
RPM_PATH=/root/rpmbuild/RPMS/x86_64/${KM_NV}-1.el6.x86_64.rpm

checkRequiredFiles(){
	if [ ! -e ${TEMPLATE_FILE} ];
	then
		echo "${TEMPLATE_FILE} doesn't exist"
		exit 2
	fi

	if [ ! -e ${KM_GZ_FILE} ];
	then
		echo "${KM_GZ_FILE} doesn't exist"
		exit 2
	fi
}

makeKernelModule(){
	KO=$1
	if [ -e ${KO} ];
	then
		return
	fi
	
	rm -rf ${UNTAR_DIR}
		tar zxvf ${KM_GZ_FILE}

	SRC_DIR=${UNTAR_DIR}/src

	cd ${SRC_DIR}
	make
	
	if [ ! -e "${KM_NAME}.ko" ];
	then
		echo "Can't find ${KM_NAME}.ko"
		exit 2
	fi	
}

makeKMRPM(){
	MK_RPM_DIR=${KM_NAME}_driver

	rm -rf ${MK_RPM_DIR}
	mkdir ${MK_RPM_DIR}
	cp ${TEMPLATE_FILE} ${MK_RPM_DIR}
	cp ${KO_FILE} ${MK_RPM_DIR}

	cd ${MK_RPM_DIR}

	mkdir -p ${KM_NV}${KM_TARGET_DIR}
	cp ${KM_NAME}.ko ${KM_NV}${KM_TARGET_DIR}
	tar -czf ${KM_NV}.tar.gz ${KM_NV}
	mkdir -p /root/rpmbuild/SOURCES/
	cp ${KM_NV}.tar.gz /root/rpmbuild/SOURCES/

	sed -i 's/KM_NAME/'"${KM_NAME}"'/g' ${TEMPLATE_FILE}
	sed -i 's/KM_VER/'"${KM_VER}"'/g' ${TEMPLATE_FILE}
	sed -i 's|KM_TARGET|'"${KM_TARGET_DIR}${KM_NAME}.ko"'|g' ${TEMPLATE_FILE}

	rpmbuild -ba ${TEMPLATE_FILE}
	
	if [ -e "${RPM_PATH}" ];
	then
		echo "${RPM_PATH} found!"
	else
		echo "Can't find ${RPM_PATH}"
	fi
}

checkRequiredFiles

KO_FILE=${UNTAR_DIR}/src/${KM_NAME}.ko

makeKernelModule ${KO_FILE}

cd ${BASEPATH}

makeKMRPM
